# importing PluginConfig
from extras.plugins import PluginConfig


class PatchTrackerConfig(PluginConfig):
    name = "patch_tracker"
    verbose_name = "Patch Tracker"
    description = "Tracks pre-patches using existing NetBox tagging."
    version = "0.1"
    author = "Daniel Murphy"
    author_email = "dev@danielmurphy.email, dmurphy@pilotfiber.com"
    base_url = "patch-tracker"
    required_settings = []
    default_settings = {}

# instantiating our config
config = PatchTrackerConfig



# importing Django admin and our own database schema
from django.contrib import admin
from .models import Patch

@admin.register(Patch)
class PatchAdmin(admin.ModelAdmin):
    list_display = ('name', 'tag')


# importing Django admin and our own database schema
from django.contrib import admin
from .models import Animal

@admin.register(Animal)
class AnimalAdmin(admin.ModelAdmin):
    list_display = ('name', 'sound')


# importing models from Django
from django.db import models

# defining our class for Animal- our Animal Sounds plugin
class Animal(models.Model):
	# specifying attributes that will have columns in our new table
	name = models.CharField(max_length=50)
	sound = models.CharField(max_length=50)

	''' we learned about this in Learn Python: Classes.
	This class will give us detailed return string, in this case,
	just the instance name, if we directly print or output the instance.'''
	def __str__(self):
		return self.name


# interestingly the NTC example does not have a setup.py file. Creating to follow the documentation

'''
This file will be used to install the plugin.
According to the documenation, the primary purpose of this file is to call `setuptools` lib's `setup()` funct.
The `setup()` funct will create a python distribution package.

We can pass a number of kwargs to the function as well as plugin metadata.
'''

# importing setup from setuptools
from setuptools import find_packages, setup

# example to pull all data from README into var long_description
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()




# defining python package as generic Dan's tools
'''
Since I have read up on Distutlis, we should be specifying the two packages by name, but the netbox documentation uses this `find_packages()` func. Will test out, if it does not work, I will statically spec our packages, animal_sounds and patch_tracker.
'''
setup(
	name = "dans-netbox-plugins",
	version = "0.55",
	description = "creating example and Pilot\"s first plugin",
    long_description = long_description,
	url = "https://github.com/dmurphy112/public",
	author = "daniel murphy",
    author_email = "dev@danielmurphy.email",
	license = "Apache 2.0",
	install_requires = [],
	packages = find_packages(),
	include_package_data = True,
	zip_safe = False,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',)



# importing PluginConfig
from extras.plugins import PluginConfig

# defining config class for animal sounds
class AnimalSoundsConfig(PluginConfig):
    name = "netbox_animal_sounds"
    verbose_name = "Animal Sounds"
    description = "Tracks animal sounds, by animal."
    version = "0.1"
    author = "Daniel Murphy"
    author_email = "dev@danielmurphy.email"
    base_url = "animal-sounds"
    required_settings = []
    # default settings that will affect our plugin behavior
    default_settings = {}

# instantiating our config
config = AnimalSoundsConfig
